import pytest
from dbt.tests.adapter.utils.base_utils import BaseUtils
from dbt.tests.adapter.utils.fixture_cast_bool_to_text import (
    models__test_cast_bool_to_text_sql,
    models__test_cast_bool_to_text_yml,
)


class BaseCastBoolToText(BaseUtils):
    @pytest.fixture(scope="class")
    def models(self):
        return {
            "test_cast_bool_to_text.yml": models__test_cast_bool_to_text_yml,
            "test_cast_bool_to_text.sql": self.interpolate_macro_namespace(
                models__test_cast_bool_to_text_sql, "cast_bool_to_text"
            ),
        }


class TestCastBoolToText(BaseCastBoolToText):
    pass





from typing import List, Optional
import pytest

from dbt.tests.util import run_dbt


_DEFAULT_CHANGE_RELATION_TYPE_MODEL = """
{{ config(materialized=var('materialized')) }}

select '{{ var("materialized") }}' as materialization

{% if var('materialized') == 'incremental' and is_incremental() %}
    where 'abc' != (select max(materialization) from {{ this }})
{% endif %}
"""


class BaseChangeRelationTypeValidator:
    @pytest.fixture(scope="class")
    def models(self):
        return {
            "model_mc_modelface.sql": _DEFAULT_CHANGE_RELATION_TYPE_MODEL
        }

    def _run_and_check_materialization(self, materialization, extra_args: Optional[List] = None):
        run_args = ["run", '--vars', f'materialized: {materialization}']
        if extra_args:
            run_args.extend(extra_args)
        results = run_dbt(run_args)
        assert results[0].node.config.materialized == materialization
        assert len(results) == 1

    def test_changing_materialization_changes_relation_type(self, project):
        self._run_and_check_materialization('view')
        self._run_and_check_materialization('table')
        self._run_and_check_materialization('view')
        self._run_and_check_materialization('incremental')
        self._run_and_check_materialization('table', extra_args=['--full-refresh'])


class TestChangeRelationTypes(BaseChangeRelationTypeValidator):
    pass



import pytest
from dbt.tests.util import run_dbt

macros__test_assert_equal_sql = """
{% test assert_equal(model, actual, expected) %}
select * from {{ model }} where {{ actual }} != {{ expected }}

{% endtest %}
"""


class BaseUtils:
    # setup
    @pytest.fixture(scope="class")
    def macros(self):
        return {"test_assert_equal.sql": macros__test_assert_equal_sql}

    # make it possible to dynamically update the macro call with a namespace
    # (e.g.) 'dateadd', 'dbt.dateadd', 'dbt_utils.dateadd'
    def macro_namespace(self):
        return ""

    def interpolate_macro_namespace(self, model_sql, macro_name):
        macro_namespace = self.macro_namespace()
        return (
            model_sql.replace(f"{macro_name}(", f"{macro_namespace}.{macro_name}(")
            if macro_namespace
            else model_sql
        )

    # actual test sequence
    def test_build_assert_equal(self, project):
        run_dbt(["build"])  # seed, model, test



import dbt.task.debug


class BaseValidateConnection:
    # project need to be here otherwise some other tests might break
    def test_validate_connection(self, project, dbt_profile_data):

        dbt.task.debug.DebugTask.validate_connection(
            dbt_profile_data["test"]["outputs"]["default"]
        )


class TestValidateConnection(BaseValidateConnection):
    pass



import pytest
from dbt.tests.adapter.utils.base_array_utils import BaseArrayUtils
from dbt.tests.adapter.utils.fixture_array_concat import (
    models__array_concat_actual_sql,
    models__array_concat_expected_sql,
)


class BaseArrayConcat(BaseArrayUtils):
    @pytest.fixture(scope="class")
    def models(self):
        return {
            "actual.sql": models__array_concat_actual_sql,
            "expected.sql": models__array_concat_expected_sql,
        }


class TestArrayConcat(BaseArrayConcat):
    pass



import pytest
from dbt.tests.adapter.utils.base_utils import BaseUtils
from dbt.tests.adapter.utils.fixture_replace import (
    seeds__data_replace_csv,
    models__test_replace_sql,
    models__test_replace_yml,
)


class BaseReplace(BaseUtils):
    @pytest.fixture(scope="class")
    def seeds(self):
        return {"data_replace.csv": seeds__data_replace_csv}

    @pytest.fixture(scope="class")
    def models(self):
        return {
            "test_replace.yml": models__test_replace_yml,
            "test_replace.sql": self.interpolate_macro_namespace(
                models__test_replace_sql, "replace"
            ),
        }


class TestReplace(BaseReplace):
    pass
